﻿using System;
using System.IO;
using Android.App;
using Android.OS;
using Android.Support.V7.App;
using Android.Widget;

using Syncfusion.Pdf.Parsing;
using Syncfusion.Pdf.Interactive;
using Syncfusion.SfPdfViewer.Android;

namespace PDFTest
{
    [Activity(Label = "@string/app_name", Theme = "@style/AppTheme.NoActionBar", MainLauncher = true)]
    public class MainActivity : AppCompatActivity
    {
        private MemoryStream docStream = null;
        private SfPdfViewer pdfView = null;

        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);
            Xamarin.Essentials.Platform.Init(this, savedInstanceState);
            SetContentView(Resource.Layout.activity_main);

            Button btnLoad = FindViewById<Button>(Resource.Id.btnLoad);
            btnLoad.Click += BtnLoad_Click;

            pdfView = FindViewById<SfPdfViewer>(Resource.Id.vPdfViewer);
            pdfView.BookmarkPaneVisible = false;
            pdfView.BookmarkNavigationEnabled = false;

            pdfView.EnableDocumentLinkAnnotation = false;
            pdfView.IsTextSearchEnabled = false;
            pdfView.Toolbar.Enabled = false;
        }

        private void BtnLoad_Click(object sender, EventArgs e)
        {
            if (docStream != null)
            {
                pdfView.Unload();
                docStream.Dispose();
                docStream = null;
            }

            using (StreamReader reader = new StreamReader(Assets.Open("FreeTextAnnotation.pdf")))
            {
                docStream = new MemoryStream();
                reader.BaseStream.CopyTo(docStream);
            }

            // In Vol 4 2019, the problem "Modified FreeTextAnnotation content is not updated in resultant PDF with Korean characters" is fixed.
            // https://www.syncfusion.com/feedback/10375/modified-freetextannotation-content-is-not-updated-in-resultant-pdf-with-korean
            // but, there is issue(encoding problem?) that the annotation is not changed properply when the new content is mixed in ascii letters and Korean letters 

            PdfLoadedDocument document = new PdfLoadedDocument(docStream);
            for (int i = 0; i < document.Pages.Count; i++)
            {
                int nCount = 0;
                foreach (PdfLoadedAnnotation Annot in document.Pages[i].Annotations)
                {
                    if (Annot is PdfLoadedFreeTextAnnotation)
                    {
                        PdfLoadedFreeTextAnnotation TextAnnot = Annot as PdfLoadedFreeTextAnnotation;
                        if (String.IsNullOrWhiteSpace(TextAnnot.Text) == false)
                        {
                            string szNewContent = "";
                            if (nCount == 0)
                            {
                                // if new content is in Korean Only => Successfully changed.
                                szNewContent = "텍스트 편집";
                            }
                            else if (nCount == 1)
                            {
                                // if new content has Korean letter and '(20)', it is not properly changed.
                                szNewContent = "다른 텍스트(20)";
                            }
                            else if (nCount == 2)
                            {
                                // if new content has English letter and '(20)' => Successfully changed.
                                szNewContent = "New Text(20)";
                            }
                            else if (nCount == 3)
                            {
                                // if new content has Korean letter and digits, it is not properly changed.
                                szNewContent = "한동리 1638번지";
                            }
                            else if (nCount == 4)
                            {
                                // if new content has Korean letter and some symbols, it is not properly changed.
                                szNewContent = " 한동리 번지!@#$";
                            }
                            else if (nCount == 5)
                            {
                                // if new content has Korean letter and some symbols => Successfully changed.
                                szNewContent = "다른 텍스트 != 20";
                            }

                            // Apply new content.
                            Annot.Text = szNewContent;   // Change text content 
                            nCount++;
                        }
                    }
                }
            }

            //Save the document to the stream
            document.Save(docStream);

            // Show It
            pdfView.LoadDocument(docStream);
       }
    }
}

